pub fn create_headless_robot_test<F>(
width: u32,
height: u32,
content: F,
) -> RobotTestRule<TestRenderer>where
F: FnMut() + 'static,Expand description
Create a headless robot test rule for testing without a real renderer.
This is useful for fast unit tests that don’t need actual rendering.