pub fn changed_pixel_count(
before: &RobotScreenshot,
after: &RobotScreenshot,
channel_threshold: u8,
) -> usizeExpand description
Count pixels that differ between two screenshots by more than channel_threshold
on any RGBA channel.
pub fn changed_pixel_count(
before: &RobotScreenshot,
after: &RobotScreenshot,
channel_threshold: u8,
) -> usizeCount pixels that differ between two screenshots by more than channel_threshold
on any RGBA channel.