pub fn run_test_composition<R>(f: impl FnOnce(&mut ComposeTestRule) -> R) -> RExpand description
Convenience helper for tests that only need temporary access to a
ComposeTestRule.
pub fn run_test_composition<R>(f: impl FnOnce(&mut ComposeTestRule) -> R) -> RConvenience helper for tests that only need temporary access to a
ComposeTestRule.